@@ -1,20 +1,29 @@
-import json
-import os
-import logging
-import time
-import ssl
 import itertools
+import json
+import logging
+import os
+import ssl
+import time
 import warnings
 import webbrowser
 from getpass import getpass
-from http.server import BaseHTTPRequestHandler, HTTPServer
+from http.server import (
+    BaseHTTPRequestHandler,
+    HTTPServer,
+    SimpleHTTPRequestHandler,
+)
 
 import tqdm
-from oauthlib.oauth2 import BackendApplicationClient, LegacyApplicationClient, \
-    OAuth2Error, WebApplicationClient, InvalidGrantError
+from oauthlib.oauth2 import (
+    BackendApplicationClient,
+    InvalidGrantError,
+    LegacyApplicationClient,
+    OAuth2Error,
+    WebApplicationClient,
+)
 from oauthlib.oauth2.rfc6749.errors import CustomOAuth2Error
-from requests_oauthlib import OAuth2Session
 from requests.adapters import HTTPAdapter
+from requests_oauthlib import OAuth2Session
 
 import alchemite_apiclient as client
 from alchemite_apiclient.exceptions import ServiceException
@@ -67,11 +76,21 @@ setTimeout(function(){window.close()}, 500);
 </script>
 </body>
 </html>
+
+
 """
 
 
 class Configuration(client.Configuration):
-    def __init__(self, *, grant_type="authorization_code", client_id="PythonClient", username="", offline=False):
+    def __init__(
+        self,
+        *,
+        grant_type="authorization_code",
+        client_id="PythonClient",
+        username="",
+        offline=False,
+        host=None,
+    ):
         self.grant_type = grant_type
         self.client_id = client_id
         self.client_secret = ""
@@ -84,7 +103,7 @@ class Configuration(client.Configuration):
         self._proxy = None
         self._auth_backoff = False
 
-        super(Configuration, self).__init__()
+        super(Configuration, self).__init__(host=host)
 
     @property
     def token_endpoint(self):
@@ -137,7 +156,8 @@ class Configuration(client.Configuration):
         except CustomOAuth2Error as e:
             if self.offline:
                 raise ValueError(
-                    "Error authenticating. Perhaps Offline Access not enabled for user, please disable and try again") from e
+                    "Error authenticating. Perhaps Offline Access not enabled for user, please disable and try again"
+                ) from e
             else:
                 raise e
 
@@ -178,7 +198,8 @@ class Configuration(client.Configuration):
         asking people to copy and paste urls.
         """
         authorization_url, state = self.session.authorization_url(
-            self.auth_endpoint)
+            self.auth_endpoint
+        )
         authorization_response = []
 
         class AuthServer(BaseHTTPRequestHandler):
@@ -187,12 +208,18 @@ class Configuration(client.Configuration):
                 # though as its entirely local we use http for the final
                 # redirect to avoid cert management
                 authorization_response.append(
-                    f"https://localhost:8497{self.path}")
+                    f"https://localhost:8497{self.path}"
+                )
                 self.send_response_only(200)
+                self.send_header("Server", self.version_string())
+                self.send_header("Date", self.date_time_string())
+                self.send_header("Content-type", "text/html")
+                data = auth_redirect_page.encode("utf-8")
+                self.send_header("Content-Length", str(len(data)))
                 self.end_headers()
-                self.wfile.write(auth_redirect_page.encode("utf-8"))
+                self.wfile.write(data)
 
-        with HTTPServer(('localhost', 8497), AuthServer) as httpd:
+        with HTTPServer(("localhost", 8497), AuthServer) as httpd:
             webbrowser.open_new(f"{authorization_url}")
 
             while len(authorization_response) == 0:
@@ -211,7 +238,7 @@ class Configuration(client.Configuration):
         if not self.offline:
             return False
         if os.path.exists(TOKEN_FILE):
-            with open(TOKEN_FILE, 'r') as file:
+            with open(TOKEN_FILE, "r") as file:
                 offline_token = file.read()
                 self._offline_token = offline_token
                 try:
@@ -224,14 +251,16 @@ class Configuration(client.Configuration):
     def save_offline(self, token):
         if not self.offline:
             return
-        if token['refresh_token'] == self._offline_token:
+        if token["refresh_token"] == self._offline_token:
             # Nothing to update
             return
-        if ('offline_access' in token['scope']
-            and token['refresh_expires_in'] == 0):
-            self._offline_token = token['refresh_token']
-            with open(TOKEN_FILE, 'w') as file:
-                file.write(token['refresh_token'])
+        if (
+            "offline_access" in token["scope"]
+            and token["refresh_expires_in"] == 0
+        ):
+            self._offline_token = token["refresh_token"]
+            with open(TOKEN_FILE, "w") as file:
+                file.write(token["refresh_token"])
 
     def refresh_token(self):
         # Make request with 'grant_type'='refresh_token'
@@ -247,13 +276,15 @@ class Configuration(client.Configuration):
     def access_token(self):
         if not self.token:
             self.token = self.get_token()
-        elif (self.token_expired() and not self._auth_backoff) or self.token_expired(soft=False):
+        elif (
+            self.token_expired() and not self._auth_backoff
+        ) or self.token_expired(soft=False):
             try:
                 self.refresh_token()
                 if self.token["expires_in"] <= 10 and not self._auth_backoff:
                     # Refresh token expiring, causing auth flooding
                     self.token = self.get_token()
-                    if self.token['expires_in'] <= 10:
+                    if self.token["expires_in"] <= 10:
                         # Fresh token didn't help, so backoff until token fully expires
                         self._auth_backoff = True
             except InvalidGrantError:
@@ -287,6 +318,7 @@ class Configuration(client.Configuration):
             )
             # Debug shim
             import os
+
             os.environ["OAUTHLIB_INSECURE_TRANSPORT"] = "1"
             self.verify_ssl = False
 
@@ -298,8 +330,15 @@ class Configuration(client.Configuration):
     def proxy(self, val):
         self._proxy = val
         if val is not None:
-            os.environ['http_proxy'] = val
-            os.environ['https_proxy'] = val
+            os.environ["http_proxy"] = val
+            os.environ["https_proxy"] = val
+
+    def get_host_from_settings(self, index, variables=None, servers=None):
+        return (
+            super()
+            .get_host_from_settings(index, variables=variables, servers=servers)
+            .rstrip("/")
+        )
 
     def auth_settings(self):
         """Gets Auth Settings dict for api client.
@@ -311,11 +350,11 @@ class Configuration(client.Configuration):
         auth = {}
         access_token = self.access_token
         if access_token is not None:
-            auth['oauth'] = {
-                'type': 'oauth2',
-                'in': 'header',
-                'key': 'Authorization',
-                'value': 'Bearer ' + access_token
+            auth["oauth"] = {
+                "type": "oauth2",
+                "in": "header",
+                "key": "Authorization",
+                "value": "Bearer " + access_token,
             }
         return auth
 
@@ -350,7 +389,7 @@ def await_trained(get_model):
             training_progress = model.training_progress
             hyperopt_progress = model.hyperparameter_optimization_progress
             validation_method = str(model.validation_method)
-            model_status = str(model.status)            
+            model_status = str(model.status)
 
             if training_progress is None:
                 training_progress = 0
