@@ -58,6 +58,7 @@ from alchemite_apiclient.model.dataset_query_request_row_ids import DatasetQuery
 from alchemite_apiclient.model.dataset_query_request_sort import DatasetQueryRequestSort
 from alchemite_apiclient.model.dataset_query_response import DatasetQueryResponse
 from alchemite_apiclient.model.dataset_query_response_result import DatasetQueryResponseResult
+from alchemite_apiclient.model.dataset_sharing import DatasetSharing
 from alchemite_apiclient.model.dependent_col_fn_arg_col import DependentColFnArgCol
 from alchemite_apiclient.model.dependent_col_fn_arg_col_weights import DependentColFnArgColWeights
 from alchemite_apiclient.model.dependent_col_fn_arg_constant_sum import DependentColFnArgConstantSum
@@ -117,19 +118,25 @@ from alchemite_apiclient.model.importance_request import ImportanceRequest
 from alchemite_apiclient.model.impute_request import ImputeRequest
 from alchemite_apiclient.model.inline_response200 import InlineResponse200
 from alchemite_apiclient.model.inline_response2001 import InlineResponse2001
+from alchemite_apiclient.model.inline_response2002 import InlineResponse2002
+from alchemite_apiclient.model.inline_response2003 import InlineResponse2003
 from alchemite_apiclient.model.int_cat_arr import IntCatArr
 from alchemite_apiclient.model.job_patch import JobPatch
 from alchemite_apiclient.model.load_request import LoadRequest
 from alchemite_apiclient.model.max import Max
+from alchemite_apiclient.model.metadata_optimization_job import MetadataOptimizationJob
+from alchemite_apiclient.model.metadata_suggest_additional_job import MetadataSuggestAdditionalJob
+from alchemite_apiclient.model.metadata_suggest_historic_job import MetadataSuggestHistoricJob
 from alchemite_apiclient.model.min import Min
 from alchemite_apiclient.model.model import Model
 from alchemite_apiclient.model.model_column_info import ModelColumnInfo
+from alchemite_apiclient.model.model_id_stub import ModelIDStub
 from alchemite_apiclient.model.model_patch import ModelPatch
 from alchemite_apiclient.model.model_permitted_column_relationships import ModelPermittedColumnRelationships
 from alchemite_apiclient.model.model_query import ModelQuery
+from alchemite_apiclient.model.model_sharing import ModelSharing
 from alchemite_apiclient.model.model_status import ModelStatus
 from alchemite_apiclient.model.model_validation_methods import ModelValidationMethods
-from alchemite_apiclient.model.models_dataset_put_request import ModelsDatasetPutRequest
 from alchemite_apiclient.model.models_id_additive_sensitivity_origin import ModelsIdAdditiveSensitivityOrigin
 from alchemite_apiclient.model.models_id_train_permitted_column_relationships import ModelsIdTrainPermittedColumnRelationships
 from alchemite_apiclient.model.models_metadata_filters import ModelsMetadataFilters
@@ -167,6 +174,7 @@ from alchemite_apiclient.model.ot_sample_def_categorical import OTSampleDefCateg
 from alchemite_apiclient.model.ot_sample_def_continuous import OTSampleDefContinuous
 from alchemite_apiclient.model.ot_sample_definition import OTSampleDefinition
 from alchemite_apiclient.model.ot_set_inputs import OTSetInputs
+from alchemite_apiclient.model.optimization_job import OptimizationJob
 from alchemite_apiclient.model.optimize_request import OptimizeRequest
 from alchemite_apiclient.model.outliers_request import OutliersRequest
 from alchemite_apiclient.model.output_tolerance_request import OutputToleranceRequest
@@ -182,6 +190,7 @@ from alchemite_apiclient.model.part_get_optimize_done_result_array import PartGe
 from alchemite_apiclient.model.part_get_suggest_additional import PartGetSuggestAdditional
 from alchemite_apiclient.model.part_get_suggest_historic import PartGetSuggestHistoric
 from alchemite_apiclient.model.part_get_suggest_initial import PartGetSuggestInitial
+from alchemite_apiclient.model.part_get_suggest_initial_sharing import PartGetSuggestInitialSharing
 from alchemite_apiclient.model.part_new_columns import PartNewColumns
 from alchemite_apiclient.model.part_tar_fn_above import PartTarFnAbove
 from alchemite_apiclient.model.part_tar_fn_below import PartTarFnBelow
@@ -191,6 +200,7 @@ from alchemite_apiclient.model.part_tar_fn_single_tar import PartTarFnSingleTar
 from alchemite_apiclient.model.part_tar_fn_sum import PartTarFnSum
 from alchemite_apiclient.model.part_tar_fn_weighted_sum import PartTarFnWeightedSum
 from alchemite_apiclient.model.predict_request import PredictRequest
+from alchemite_apiclient.model.predict_trendline_request import PredictTrendlineRequest
 from alchemite_apiclient.model.prediction import Prediction
 from alchemite_apiclient.model.project import Project
 from alchemite_apiclient.model.project_bulk_model import ProjectBulkModel
@@ -219,11 +229,16 @@ from alchemite_apiclient.model.sensitivity_request import SensitivityRequest
 from alchemite_apiclient.model.set_inputs import SetInputs
 from alchemite_apiclient.model.share_group import ShareGroup
 from alchemite_apiclient.model.string_cat_arr import StringCatArr
+from alchemite_apiclient.model.suggest_additional_job import SuggestAdditionalJob
+from alchemite_apiclient.model.suggest_additional_metadata_filters import SuggestAdditionalMetadataFilters
+from alchemite_apiclient.model.suggest_additional_metadata_sort import SuggestAdditionalMetadataSort
 from alchemite_apiclient.model.suggest_additional_parameters import SuggestAdditionalParameters
 from alchemite_apiclient.model.suggest_additional_parameters_all_of import SuggestAdditionalParametersAllOf
+from alchemite_apiclient.model.suggest_additional_query import SuggestAdditionalQuery
 from alchemite_apiclient.model.suggest_additional_request import SuggestAdditionalRequest
 from alchemite_apiclient.model.suggest_additional_request_all_of import SuggestAdditionalRequestAllOf
 from alchemite_apiclient.model.suggest_additional_result import SuggestAdditionalResult
+from alchemite_apiclient.model.suggest_historic_job import SuggestHistoricJob
 from alchemite_apiclient.model.suggest_historic_parameters import SuggestHistoricParameters
 from alchemite_apiclient.model.suggest_historic_request import SuggestHistoricRequest
 from alchemite_apiclient.model.suggest_historic_result import SuggestHistoricResult
