@@ -13,6 +13,13 @@ configuration.credentials = "credentials.json"
 
 model_id_to_delete = "XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX"
 
+# Check we can access the API by getting the version number from GET /version
+api_response = api_default.version_get()
+print("------ API & Python Client Versions ------")
+print(api_response)
+print(f"Python client version: {client.__version__} (latest: {api_response['api_definition_version']})")
+print("------------------------------------------")
+
 # Can iterate through all models and delete a model with a particular ID.
 # IDs are unique to each model and dataset so this guarantees we only delete
 # the one model we want.
