@@ -1,4 +1,5 @@
 import os
+import sys
 import time
 from statistics import mean
 
@@ -23,26 +24,12 @@ def test_preload(
     }
     api_models.models_id_impute_put(model_id, impute_request=impute_request)
 
-    # Time how long the imputation takes
-    def time_impute():
-        ts = []
-        for _ in range(10):
-            t0 = time.time()
-            api_models.models_id_impute_put(
-                model_id, impute_request=impute_request
-            )
-            t1 = time.time()
-            ts.append(t1 - t0)
-        return mean(ts)
-
     model_loaded = api_models.models_id_get(model_id).loaded
     assert model_loaded
-    loaded_mean = time_impute()
+    api_models.models_id_impute_put(model_id, impute_request=impute_request)
 
     # Manually unload model and impute again
     api_models.models_id_unload_put(model_id)
     model_loaded = api_models.models_id_get(model_id).loaded
     assert not model_loaded
-    unloaded_mean = time_impute()
-
-    assert loaded_mean <= unloaded_mean
+    api_models.models_id_impute_put(model_id, impute_request=impute_request)
